@@ -14,6 +14,7 @@
 
 import argparse
 import re
+import json
 
 from .meta import NAME, VERSION, DESCRIPTION
 
@@ -50,12 +51,6 @@ group_main.add_argument(
     action='append',
 )
 
-group_main.add_argument(
-    '--extra-properties',
-    help='Extra properties (key-value pairs) that can be used by specific templates'
-         ' Example: {x:y,a:b}'
-)
-
 group_main.add_argument(
     '--opt',
     metavar='KEY=VALUE',
@@ -71,6 +66,13 @@ group_extra = parser.add_argument_group(
     title='Extra Options'
 )
 
+group_extra.add_argument(
+    '--extra-properties',
+    help='Extra properties (key-value pairs) that can be used by specific templates'
+         ' Example: "{x:y,a:b}"',
+    type=json.loads
+)
+
 group_extra.add_argument(
     '-f', '--filter',
     help='Regular expression enabled output filename filter,'
